@@ -7,9 +7,9 @@ use warnings;
 #use Data::Dmp;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-17'; # DATE
+our $DATE = '2022-09-09'; # DATE
 our $DIST = 'Data-Sah-FilterBundle-Phone'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 sub meta {
     +{
@@ -63,7 +63,7 @@ Data::Sah::Filter::perl::Phone::format_idn - Format Indonesian phone number with
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Filter::perl::Phone::format_idn (from Perl distribution Data-Sah-FilterBundle-Phone), released on 2022-07-17.
+This document describes version 0.003 of Data::Sah::Filter::perl::Phone::format_idn (from Perl distribution Data-Sah-FilterBundle-Phone), released on 2022-09-09.
 
 =head1 SYNOPSIS
 
@@ -125,9 +125,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
