@@ -3,9 +3,9 @@ package Data::Sah::FilterBundle::Phone;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-17'; # DATE
+our $DATE = '2022-09-09'; # DATE
 our $DIST = 'Data-Sah-FilterBundle-Phone'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Sah filters related to phone numbers
@@ -22,7 +22,7 @@ Data::Sah::FilterBundle::Phone - Sah filters related to phone numbers
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::FilterBundle::Phone (from Perl distribution Data-Sah-FilterBundle-Phone), released on 2022-07-17.
+This document describes version 0.003 of Data::Sah::FilterBundle::Phone (from Perl distribution Data-Sah-FilterBundle-Phone), released on 2022-09-09.
 
 =head1 DESCRIPTION
 
@@ -30,11 +30,11 @@ This distribution contains the following L<Sah> filter rule modules:
 
 =over
 
-=item * L<Data::Sah::Filter::perl::Phone::format>
+=item * L<Data::Sah::Filter::perl::Phone::format_idn>
 
 =item * L<Data::Sah::Filter::perl::Phone::format_idnlocal_nospace>
 
-=item * L<Data::Sah::Filter::perl::Phone::format_idn>
+=item * L<Data::Sah::Filter::perl::Phone::format>
 
 =item * L<Data::Sah::Filter::perl::Phone::format_idn_nospace>
 
@@ -65,9 +65,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
